@@ -5,12 +5,11 @@
  *
  */
 
-#ifndef RESOURCEMODEL_H
-#define RESOURCEMODEL_H
+#pragma once
 
 #include "resourceitem.h"
 
-#include <KLDAP/LdapClientSearch>
+#include <KLDAPWidgets/LdapClientSearch>
 
 #include <QAbstractItemModel>
 #include <QModelIndex>
@@ -31,18 +30,18 @@ public:
     explicit ResourceModel(const QStringList &headers, QObject *parent = nullptr);
     ~ResourceModel() override;
 
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
-    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
-    Q_REQUIRED_RESULT QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
-    Q_REQUIRED_RESULT QModelIndex parent(const QModelIndex &index) const override;
+    [[nodiscard]] QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QModelIndex parent(const QModelIndex &index) const override;
 
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    Q_REQUIRED_RESULT Qt::ItemFlags flags(const QModelIndex &index) const override;
+    [[nodiscard]] Qt::ItemFlags flags(const QModelIndex &index) const override;
 
-    Q_REQUIRED_RESULT bool removeRows(int position, int rows, const QModelIndex &parent = QModelIndex()) override;
+    [[nodiscard]] bool removeRows(int position, int rows, const QModelIndex &parent = QModelIndex()) override;
 
 private:
     ResourceItem *getItem(const QModelIndex &index) const;
@@ -64,12 +63,12 @@ private:
     /* Search for collections of resources
      *
      */
-    KLDAP::LdapClientSearch *mLdapSearchCollections = nullptr;
+    KLDAPWidgets::LdapClientSearch *mLdapSearchCollections = nullptr;
 
     /* Search for matching resources
      *
      */
-    KLDAP::LdapClientSearch *mLdapSearch = nullptr;
+    KLDAPWidgets::LdapClientSearch *mLdapSearch = nullptr;
 
     /* Map from dn of resource -> collectionItem
      * A Resource can be part of different collection, so a QMuliMap is needed
@@ -101,12 +100,11 @@ private:
     /* Slot for founded collections
      *
      */
-    void slotLDAPCollectionData(const KLDAP::LdapResultObject::List &);
+    void slotLDAPCollectionData(const KLDAPWidgets::LdapResultObject::List &);
 
     /* Slot for matching resources
      *
      */
-    void slotLDAPSearchData(const KLDAP::LdapResultObject::List &);
+    void slotLDAPSearchData(const KLDAPWidgets::LdapResultObject::List &);
 };
 }
-#endif // RESOURCEMODEL_H
